Draw defect projections for spheroids, spherocylinders or spheres.
The method first constructs the projected objects sampling some points
on the borders and calculates the convex hull of such points.
The defect object as returned by simFracture
and used to show the accumulated defects.
drawDefectProjections(F, D, ...)# S3 method for oblate
drawDefectProjections(F, D, ...)
# S3 method for prolate
drawDefectProjections(F, D, ...)
# S3 method for cylinder
drawDefectProjections(F, D, ...)
# S3 method for sphere
drawDefectProjections(F, D, ...)
geometry system
defects object
further arguments passed to
getSphereProjection,
getSpheroidProjection,
getCylinderProjection
NULL