Learn R Programming

simLife (version 0.3)

simFerrit: Simulate a second phase

Description

Poisson spheroid system

Usage

simFerrit(param, lam, box, mu = c(0, 1, 0), verbose = FALSE)

Arguments

param

simulation parameter list

lam

the intensity parameter of the underlying Poisson point process

box

the simulation box

mu

reference direction of particles, here mu=c(0,1,0) (default)

verbose

logical, ignored

Value

list of spheroids

Details

The function generates a system of constant size Poisson spheroidal objects with intensity lam and random planar orientation distribution. The spheroidal objects are labeled by \(F\) to denote the secondary particle phase, denoting for instance some disturbing ferrit inclusions in real life specimen.

See Also

simSpheroidSystem