Learn R Programming

simLife (version 0.3)

simParticle: Simulate particle system (primary phase)

Description

Poisson spheroid system

Usage

simParticle(theta, lam, box, mu = c(0, 1, 0), verbose = FALSE)

Arguments

theta

simulation parameter list

lam

intensity parameter of the underlying Poisson point process

box

the simulation box

mu

reference direction of particles, here mu=c(0,1,0) (default)

verbose

logical, not used yet

Value

list of spheroids

Details

The function generates a constant size Poisson spheroid system with intensity parameter lam and random planar (with respect to the xz plane) orientation distribution. The spheroids are labeled by \(P\) to denote the primary particle phase which usually plays the role of some reinforcement material type in real life specimen. In order to simulate the fatigue lifetime model, see simDefect, a non-overlapping configuration of particles is required which could be generated for instance by application of the the well-known random sequential adsorption (RSA) method, see rsa. Alternatively the Force-biased algorithm could be used as well, see reference below.

References

  • A. Bezrukov and D. Stoyan. Simulation and statistical analysis of random packings of ellipsoids. Particle & Particle Systems Characterization, 23(5):388 - 398, 2006.

  • J.W. Evans. Random and cooperative sequential adsorption. Rev. Mod. Phys., 65: 1281-1304. 1993.

See Also

simSpheroidSystem