Poisson spheroid system
simFerrit(param, lam, box, mu = c(0, 1, 0), verbose = FALSE)simulation parameter list
the intensity parameter of the underlying Poisson point process
the simulation box
reference direction of particles, here mu=c(0,1,0) (default)
logical, ignored
list of spheroids
The function generates a system of constant size Poisson spheroidal objects with intensity lam and random planar
orientation distribution. The spheroidal objects are labeled by \(F\) to denote the secondary
particle phase, denoting for instance some disturbing ferrit inclusions in real life specimen.