Poisson spheroid system
simParticle(theta, lam, box, mu = c(0, 1, 0), verbose = FALSE)simulation parameter list
intensity parameter of the underlying Poisson point process
the simulation box
reference direction of particles, here mu=c(0,1,0) (default)
logical, not used yet
list of spheroids
The function generates a constant size Poisson spheroid system with intensity parameter lam
and random planar (with respect to the xz plane) orientation distribution. The spheroids are labeled
by \(P\) to denote the primary particle phase which usually plays the role of some reinforcement
material type in real life specimen. In order to simulate the fatigue lifetime model, see simDefect,
a non-overlapping configuration of particles is required which could be generated for instance by application of
the the well-known random sequential adsorption (RSA) method, see rsa. Alternatively the Force-biased
algorithm could be used as well, see reference below.
A. Bezrukov and D. Stoyan. Simulation and statistical analysis of random packings of ellipsoids. Particle & Particle Systems Characterization, 23(5):388 - 398, 2006.
J.W. Evans. Random and cooperative sequential adsorption. Rev. Mod. Phys., 65: 1281-1304. 1993.